@@ -1,20 +1,40 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2006 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
 ** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** License versions 2.0 or 3.0 as published by the Free Software
+** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file.  Alternatively you may (at
+** your option) use any later version of the GNU General Public
+** License if such license has been publicly approved by Trolltech ASA
+** (or its successors, if any) and the KDE Free Qt Foundation. In
+** addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.2, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
 **
-** If you are unsure which license is appropriate for your use, please
+** Please review the following information to ensure GNU General
+** Public Licensing requirements will be met:
+** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
+** you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech, as the sole
+** copyright holder for Qt Designer, grants users of the Qt/Eclipse
+** Integration plug-in the right for the Qt/Eclipse Integration to
+** link to functionality provided by Qt Designer and its related
+** libraries.
+**
+** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
+** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
+** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
+** granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -51,7 +71,6 @@ protected:
     Qt::KeyboardModifiers modState;
 };
 
-
 class Q_GUI_EXPORT QMouseEvent : public QInputEvent
 {
 public:
@@ -139,6 +158,7 @@ protected:
 };
 #endif
 
+#ifndef QT_NO_TABLETEVENT
 class Q_GUI_EXPORT QTabletEvent : public QInputEvent
 {
 public:
@@ -181,24 +201,36 @@ protected:
     // new devices coming along, and there seem to be "holes" in the
     // OS-specific events for this.
     void *mExtra;
-
 };
-
+#endif // QT_NO_TABLETEVENT
 
 class Q_GUI_EXPORT QKeyEvent : public QInputEvent
 {
 public:
-    QKeyEvent(Type type, int key, Qt::KeyboardModifiers modifiers,
-              const QString& text = QString(),
+    QKeyEvent(Type type, int key, Qt::KeyboardModifiers modifiers, const QString& text = QString(),
               bool autorep = false, ushort count = 1);
     ~QKeyEvent();
 
     int key() const { return k; }
+#ifndef QT_NO_SHORTCUT
+    bool matches(QKeySequence::StandardKey key) const;
+#endif
     Qt::KeyboardModifiers modifiers() const;
     inline QString text() const { return txt; }
     inline bool isAutoRepeat() const { return autor; }
     inline int count() const { return int(c); }
 
+    // Functions for the extended key event information
+    static QKeyEvent *createExtendedKeyEvent(Type type, int key, Qt::KeyboardModifiers modifiers,
+                                             quint32 nativeScanCode, quint32 nativeVirtualKey,
+                                             quint32 nativeModifiers,
+                                             const QString& text = QString(), bool autorep = false,
+                                             ushort count = 1);
+    inline bool hasExtendedInfo() const { return reinterpret_cast<const QKeyEvent*>(d) == this; }
+    quint32 nativeScanCode() const;
+    quint32 nativeVirtualKey() const;
+    quint32 nativeModifiers() const;
+
 #ifdef QT3_SUPPORT
     inline QT3_SUPPORT_CONSTRUCTOR QKeyEvent(Type type, int key, int /*ascii*/,
                                            int modifiers, const QString& text = QString(),
@@ -239,6 +271,7 @@ public:
                   Popup=Qt::PopupFocusReason, Shortcut=Qt::ShortcutFocusReason };
 #endif
     Qt::FocusReason reason();
+    Qt::FocusReason reason() const;
 
 private:
     Qt::FocusReason m_reason;
@@ -256,7 +289,7 @@ public:
     inline const QRegion &region() const { return m_region; }
 
 #ifdef QT3_SUPPORT
-    QT_COMPAT_CONSTRUCTOR QPaintEvent(const QRegion &paintRegion, const QRect &paintRect);
+    QT3_SUPPORT_CONSTRUCTOR QPaintEvent(const QRegion &paintRegion, const QRect &paintRect);
     inline QT3_SUPPORT bool erased() const { return m_erased; }
     inline QT3_SUPPORT void setErased(bool b) { m_erased = b; }
 #endif
@@ -342,7 +375,6 @@ public:
     ~QHideEvent();
 };
 
-
 class Q_GUI_EXPORT QContextMenuEvent : public QInputEvent
 {
 public:
@@ -374,6 +406,7 @@ protected:
     uint reas : 8;
 };
 
+#ifndef QT_NO_INPUTMETHOD
 class Q_GUI_EXPORT QInputMethodEvent : public QEvent
 {
 public:
@@ -412,6 +445,7 @@ private:
     int replace_from;
     int replace_length;
 };
+#endif // QT_NO_INPUTMETHOD
 
 #ifndef QT_NO_DRAGANDDROP
 
@@ -546,7 +580,7 @@ private:
     QPoint gp;
 };
 
-
+#ifndef QT_NO_STATUSTIP
 class Q_GUI_EXPORT QStatusTipEvent : public QEvent
 {
 public:
@@ -557,7 +591,9 @@ public:
 private:
     QString s;
 };
+#endif
 
+#ifndef QT_NO_WHATSTHIS
 class Q_GUI_EXPORT QWhatsThisClickedEvent : public QEvent
 {
 public:
@@ -568,8 +604,9 @@ public:
 private:
     QString s;
 };
+#endif
 
-
+#ifndef QT_NO_ACTION
 class Q_GUI_EXPORT QActionEvent : public QEvent
 {
     QAction *act, *bef;
@@ -580,7 +617,7 @@ public:
     inline QAction *action() const { return act; }
     inline QAction *before() const { return bef; }
 };
-
+#endif
 
 class Q_GUI_EXPORT QFileOpenEvent : public QEvent
 {
@@ -593,6 +630,7 @@ private:
     QString f;
 };
 
+#ifndef QT_NO_TOOLBAR
 class Q_GUI_EXPORT QToolBarChangeEvent : public QEvent
 {
 public:
@@ -603,7 +641,9 @@ public:
 private:
     uint tog : 1;
 };
+#endif
 
+#ifndef QT_NO_SHORTCUT
 class Q_GUI_EXPORT QShortcutEvent : public QEvent
 {
 public:
@@ -611,14 +651,19 @@ public:
     ~QShortcutEvent();
 
     inline const QKeySequence &key() { return sequence; }
+    inline const QKeySequence &key() const { return sequence; }
     inline int shortcutId() { return sid; }
+    inline int shortcutId() const { return sid; }
     inline bool isAmbiguous() { return ambig; }
+    inline bool isAmbiguous() const { return ambig; }
 protected:
     QKeySequence sequence;
     bool ambig;
     int  sid;
 };
+#endif
 
+#ifndef QT_NO_CLIPBOARD
 class Q_GUI_EXPORT QClipboardEvent : public QEvent
 {
 public:
@@ -627,6 +672,7 @@ public:
 
     QEventPrivate *data() { return d; };
 };
+#endif
 
 class Q_GUI_EXPORT QWindowStateChangeEvent: public QEvent
 {
@@ -658,6 +704,11 @@ private:
 Q_GUI_EXPORT QDebug operator<<(QDebug, const QEvent *);
 #endif
 
+#ifndef QT_NO_SHORTCUT
+inline bool operator==(QKeyEvent *e, QKeySequence::StandardKey key){return (e ? e->matches(key) : false);}
+inline bool operator==(QKeySequence::StandardKey key, QKeyEvent *e){return (e ? e->matches(key) : false);}
+#endif // QT_NO_SHORTCUT
+
 QT_END_HEADER
 
 #endif // QEVENT_H
