@@ -1,20 +1,40 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the QtNetwork module of the Qt Toolkit.
 **
 ** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** License versions 2.0 or 3.0 as published by the Free Software
+** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file.  Alternatively you may (at
+** your option) use any later version of the GNU General Public
+** License if such license has been publicly approved by Trolltech ASA
+** (or its successors, if any) and the KDE Free Qt Foundation. In
+** addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.2, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
 **
-** If you are unsure which license is appropriate for your use, please
+** Please review the following information to ensure GNU General
+** Public Licensing requirements will be met:
+** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
+** you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech, as the sole
+** copyright holder for Qt Designer, grants users of the Qt/Eclipse
+** Integration plug-in the right for the Qt/Eclipse Integration to
+** link to functionality provided by Qt Designer and its related
+** libraries.
+**
+** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
+** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
+** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
+** granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -29,6 +49,8 @@
 #include <QtCore/qmap.h>
 #include <QtCore/qpair.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Network)
 
 #ifndef QT_NO_HTTP
@@ -36,6 +58,9 @@ QT_MODULE(Network)
 class QTcpSocket;
 class QTimerEvent;
 class QIODevice;
+class QAuthenticator;
+class QNetworkProxy;
+class QSslError;
 
 class QHttpPrivate;
 
@@ -60,7 +85,7 @@ public:
     QStringList allValues(const QString &key) const;
     void removeValue(const QString &key);
     void removeAllValues(const QString &key);
-    
+
     bool hasContentLength() const;
     uint contentLength() const;
     void setContentLength(int len);
@@ -148,12 +173,16 @@ class Q_NETWORK_EXPORT QHttp : public QObject
     Q_OBJECT
 
 public:
+    enum ConnectionMode {
+        ConnectionModeHttp,
+        ConnectionModeHttps
+    };
+    
     explicit QHttp(QObject *parent = 0);
     QHttp(const QString &hostname, quint16 port = 80, QObject *parent = 0);
+    QHttp(const QString &hostname, ConnectionMode mode, quint16 port = 0, QObject *parent = 0);
     virtual ~QHttp();
 
-    int supportedOperations() const;
-
     enum State {
         Unconnected,
         HostLookup,
@@ -171,16 +200,23 @@ public:
         UnexpectedClose,
         InvalidResponseHeader,
         WrongContentLength,
-        Aborted
+        Aborted, 
+        AuthenticationRequiredError,
+        ProxyAuthenticationRequiredError
     };
 
     int setHost(const QString &hostname, quint16 port = 80);
+    int setHost(const QString &hostname, ConnectionMode mode, quint16 port = 0);
+    
     int setSocket(QTcpSocket *socket);
     int setUser(const QString &username, const QString &password = QString());
 
+#ifndef QT_NO_NETWORKPROXY
     int setProxy(const QString &host, int port,
                  const QString &username = QString(),
                  const QString &password = QString());
+    int setProxy(const QNetworkProxy &proxy);
+#endif
 
     int get(const QString &path, QIODevice *to=0);
     int post(const QString &path, QIODevice *data, QIODevice *to=0 );
@@ -216,6 +252,10 @@ public:
 public Q_SLOTS:
     void abort();
 
+#ifndef QT_NO_OPENSSL
+    void ignoreSslErrors();
+#endif
+
 Q_SIGNALS:
     void stateChanged(int);
     void responseHeaderReceived(const QHttpResponseHeader &resp);
@@ -227,17 +267,27 @@ Q_SIGNALS:
     void requestFinished(int, bool);
     void done(bool);
 
+#ifndef QT_NO_NETWORKPROXY
+    void proxyAuthenticationRequired(const QNetworkProxy &proxy, QAuthenticator *);
+#endif
+    void authenticationRequired(const QString &hostname, quint16 port, QAuthenticator *);
+
+#ifndef QT_NO_OPENSSL
+    void sslErrors(const QList<QSslError> &errors);
+#endif
+
 private:
     Q_DISABLE_COPY(QHttp)
     Q_DECLARE_PRIVATE(QHttp)
 
-    Q_PRIVATE_SLOT(d_func(), void startNextRequest())
-    Q_PRIVATE_SLOT(d_func(), void slotReadyRead())
-    Q_PRIVATE_SLOT(d_func(), void slotConnected())
-    Q_PRIVATE_SLOT(d_func(), void slotError(QAbstractSocket::SocketError))
-    Q_PRIVATE_SLOT(d_func(), void slotClosed())
-    Q_PRIVATE_SLOT(d_func(), void slotBytesWritten(qint64 numBytes))
-    Q_PRIVATE_SLOT(d_func(), void slotDoFinished())
+    Q_PRIVATE_SLOT(d_func(), void _q_startNextRequest())
+    Q_PRIVATE_SLOT(d_func(), void _q_slotReadyRead())
+    Q_PRIVATE_SLOT(d_func(), void _q_slotConnected())
+    Q_PRIVATE_SLOT(d_func(), void _q_slotError(QAbstractSocket::SocketError))
+    Q_PRIVATE_SLOT(d_func(), void _q_slotClosed())
+    Q_PRIVATE_SLOT(d_func(), void _q_slotBytesWritten(qint64 numBytes))
+    Q_PRIVATE_SLOT(d_func(), void _q_slotDoFinished())
+    Q_PRIVATE_SLOT(d_func(), void _q_slotSendRequest())
 
     friend class QHttpNormalRequest;
     friend class QHttpSetHostRequest;
@@ -250,4 +300,6 @@ private:
 
 #endif // QT_NO_HTTP
 
+QT_END_HEADER
+
 #endif // QHTTP_H
