@@ -1,20 +1,40 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
 ** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** License versions 2.0 or 3.0 as published by the Free Software
+** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file.  Alternatively you may (at
+** your option) use any later version of the GNU General Public
+** License if such license has been publicly approved by Trolltech ASA
+** (or its successors, if any) and the KDE Free Qt Foundation. In
+** addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.2, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
 **
-** If you are unsure which license is appropriate for your use, please
+** Please review the following information to ensure GNU General
+** Public Licensing requirements will be met:
+** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
+** you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech, as the sole
+** copyright holder for Qt Designer, grants users of the Qt/Eclipse
+** Integration plug-in the right for the Qt/Eclipse Integration to
+** link to functionality provided by Qt Designer and its related
+** libraries.
+**
+** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
+** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
+** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
+** granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -31,6 +51,8 @@
 #error qrect.h must be included before any header file that defines topLeft
 #endif
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Core)
 
 class Q_CORE_EXPORT QRect
@@ -130,13 +152,15 @@ public:
     bool contains(const QPoint &p, bool proper=false) const;
     bool contains(int x, int y) const; // inline methods, _don't_ merge these
     bool contains(int x, int y, bool proper) const;
-    bool contains(const QRect &r, bool proper=false) const;
-    QRect unite(const QRect &r) const;
-    QRect intersect(const QRect &r) const;
+    bool contains(const QRect &r, bool proper = false) const;
+    QRect unite(const QRect &r) const;  // ### Qt 5: make QT4_SUPPORT
+    QRect united(const QRect &other) const;
+    QRect intersect(const QRect &r) const;  // ### Qt 5: make QT4_SUPPORT
+    QRect intersected(const QRect &other) const;
     bool intersects(const QRect &r) const;
 
-    friend Q_CORE_EXPORT inline bool operator==(const QRect &, const QRect &);
-    friend Q_CORE_EXPORT inline bool operator!=(const QRect &, const QRect &);
+    friend Q_CORE_EXPORT_INLINE bool operator==(const QRect &, const QRect &);
+    friend Q_CORE_EXPORT_INLINE bool operator!=(const QRect &, const QRect &);
 
 #ifdef QT3_SUPPORT
     inline QT3_SUPPORT void rect(int *x, int *y, int *w, int *h) const { getRect(x, y, w, h); }
@@ -163,8 +187,8 @@ private:
 };
 Q_DECLARE_TYPEINFO(QRect, Q_MOVABLE_TYPE);
 
-Q_CORE_EXPORT inline bool operator==(const QRect &, const QRect &);
-Q_CORE_EXPORT inline bool operator!=(const QRect &, const QRect &);
+Q_CORE_EXPORT_INLINE bool operator==(const QRect &, const QRect &);
+Q_CORE_EXPORT_INLINE bool operator!=(const QRect &, const QRect &);
 
 
 /*****************************************************************************
@@ -452,11 +476,22 @@ inline QRect QRect::intersect(const QRect &r) const
 {
     return *this & r;
 }
+
+inline QRect QRect::intersected(const QRect &other) const
+{
+    return intersect(other);
+}
+
 inline QRect QRect::unite(const QRect &r) const
 {
     return *this | r;
 }
 
+inline QRect QRect::united(const QRect &r) const
+{
+     return unite(r);
+}
+
 inline bool operator==(const QRect &r1, const QRect &r2)
 {
     return r1.x1==r2.x1 && r1.x2==r2.x2 && r1.y1==r2.y1 && r1.y2==r2.y2;
@@ -477,6 +512,7 @@ class Q_CORE_EXPORT QRectF
 public:
     QRectF() { xp = yp = 0.; w = h = 0.; }
     QRectF(const QPointF &topleft, const QSizeF &size);
+    QRectF(const QPointF &topleft, const QPointF &bottomRight);
     QRectF(qreal left, qreal top, qreal width, qreal height);
     QRectF(const QRect &rect);
 
@@ -553,14 +589,17 @@ public:
     bool contains(const QPointF &p) const;
     bool contains(qreal x, qreal y) const;
     bool contains(const QRectF &r) const;
-    QRectF unite(const QRectF &r) const;
-    QRectF intersect(const QRectF &r) const;
+    QRectF unite(const QRectF &r) const;  // ### Qt 5: make QT4_SUPPORT
+    QRectF united(const QRectF &other) const;
+    QRectF intersect(const QRectF &r) const;  // ### Qt 5: make QT4_SUPPORT
+    QRectF intersected(const QRectF &other) const;
     bool intersects(const QRectF &r) const;
 
-    friend Q_CORE_EXPORT inline bool operator==(const QRectF &, const QRectF &);
-    friend Q_CORE_EXPORT inline bool operator!=(const QRectF &, const QRectF &);
+    friend Q_CORE_EXPORT_INLINE bool operator==(const QRectF &, const QRectF &);
+    friend Q_CORE_EXPORT_INLINE bool operator!=(const QRectF &, const QRectF &);
 
     QRect toRect() const;
+    QRect toAlignedRect() const;
 
 private:
     qreal xp;
@@ -570,8 +609,8 @@ private:
 };
 Q_DECLARE_TYPEINFO(QRectF, Q_MOVABLE_TYPE);
 
-Q_CORE_EXPORT inline bool operator==(const QRectF &, const QRectF &);
-Q_CORE_EXPORT inline bool operator!=(const QRectF &, const QRectF &);
+Q_CORE_EXPORT_INLINE bool operator==(const QRectF &, const QRectF &);
+Q_CORE_EXPORT_INLINE bool operator!=(const QRectF &, const QRectF &);
 
 
 /*****************************************************************************
@@ -599,6 +638,14 @@ inline QRectF::QRectF(const QPointF &atopLeft, const QSizeF &asize)
     h = asize.height();
 }
 
+inline QRectF::QRectF(const QPointF &atopLeft, const QPointF &abottomRight)
+{
+    xp = atopLeft.x();
+    yp = atopLeft.y();
+    w = abottomRight.x() - xp;
+    h = abottomRight.y() - yp;
+}
+
 inline QRectF::QRectF(const QRect &r)
     : xp(r.x()), yp(r.y()), w(r.width()), h(r.height())
 {
@@ -766,11 +813,22 @@ inline QRectF QRectF::intersect(const QRectF &r) const
 {
     return *this & r;
 }
+
+inline QRectF QRectF::intersected(const QRectF &r) const
+{
+    return intersect(r);
+}
+
 inline QRectF QRectF::unite(const QRectF &r) const
 {
     return *this | r;
 }
 
+inline QRectF QRectF::united(const QRectF &r) const
+{
+    return unite(r);
+}
+
 inline bool operator==(const QRectF &r1, const QRectF &r2)
 {
     return qFuzzyCompare(r1.xp, r2.xp) && qFuzzyCompare(r1.yp, r2.yp)
@@ -792,4 +850,6 @@ inline QRect QRectF::toRect() const
 Q_CORE_EXPORT QDebug operator<<(QDebug, const QRectF &);
 #endif
 
+QT_END_HEADER
+
 #endif // QRECT_H
