@@ -1,20 +1,40 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
 ** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** License versions 2.0 or 3.0 as published by the Free Software
+** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file.  Alternatively you may (at
+** your option) use any later version of the GNU General Public
+** License if such license has been publicly approved by Trolltech ASA
+** (or its successors, if any) and the KDE Free Qt Foundation. In
+** addition, as a special exception, Trolltech gives you certain
+** additional rights. These rights are described in the Trolltech GPL
+** Exception version 1.2, which can be found at
+** http://www.trolltech.com/products/qt/gplexception/ and in the file
+** GPL_EXCEPTION.txt in this package.
 **
-** If you are unsure which license is appropriate for your use, please
+** Please review the following information to ensure GNU General
+** Public Licensing requirements will be met:
+** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
+** you are unsure which license is appropriate for your use, please
 ** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
+** or contact the sales department at sales@trolltech.com.
+**
+** In addition, as a special exception, Trolltech, as the sole
+** copyright holder for Qt Designer, grants users of the Qt/Eclipse
+** Integration plug-in the right for the Qt/Eclipse Integration to
+** link to functionality provided by Qt Designer and its related
+** libraries.
+**
+** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
+** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
+** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
+** granted herein.
 **
 ** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 ** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
@@ -32,6 +52,8 @@
 #include <QtGui/qpen.h>
 #include <QtGui/qbrush.h>
 
+QT_BEGIN_HEADER
+
 QT_MODULE(Gui)
 
 class QString;
@@ -124,6 +146,7 @@ public:
         OutlinePen = 0x810,
         BackgroundBrush = 0x820,
         ForegroundBrush = 0x821,
+        // Internal to qtextlayout.cpp: ObjectSelectionBrush = 0x822
 
         // paragraph
         BlockAlignment = 0x1010,
@@ -143,7 +166,7 @@ public:
         FontSizeIncrement = FontSizeAdjustment, // old name, compat
         FontWeight = 0x2003,
         FontItalic = 0x2004,
-        FontUnderline = 0x2005,
+        FontUnderline = 0x2005, // deprecated, use TextUnderlineStyle instead
         FontOverline = 0x2006,
         FontStrikeOut = 0x2007,
         FontFixedPitch = 0x2008,
@@ -152,6 +175,8 @@ public:
         TextUnderlineColor = 0x2010,
         TextVerticalAlignment = 0x2021,
         TextOutline = 0x2022,
+        TextUnderlineStyle = 0x2023,
+        TextToolTip = 0x2024,
 
         IsAnchor = 0x2030,
         AnchorHref = 0x2031,
@@ -169,10 +194,18 @@ public:
         FramePadding = 0x4002,
         FrameWidth = 0x4003,
         FrameHeight = 0x4004,
+        FrameTopMargin    = 0x4005,
+        FrameBottomMargin = 0x4006,
+        FrameLeftMargin   = 0x4007,
+        FrameRightMargin  = 0x4008,
+        FrameBorderBrush = 0x4009,
+        FrameBorderStyle = 0x4010,
+
         TableColumns = 0x4100,
         TableColumnWidthConstraints = 0x4101,
         TableCellSpacing = 0x4102,
         TableCellPadding = 0x4103,
+        TableHeaderRowCount = 0x4104,
 
         // table cell properties
         TableCellRowSpan = 0x4810,
@@ -183,6 +216,12 @@ public:
         ImageWidth = 0x5010,
         ImageHeight = 0x5011,
 
+        // selection properties
+        FullWidthSelection = 0x06000,
+
+        // page break properties
+        PageBreakPolicy = 0x7000,
+
         // --
         UserProperty = 0x100000
     };
@@ -195,6 +234,14 @@ public:
         UserObject = 0x1000
     };
 
+    enum PageBreakFlag {
+        PageBreak_Auto = 0,
+        PageBreak_AlwaysBefore = 0x001,
+        PageBreak_AlwaysAfter  = 0x010
+        // PageBreak_AlwaysInside = 0x100
+    };
+    Q_DECLARE_FLAGS(PageBreakFlags, PageBreakFlag)
+
     QTextFormat();
 
     explicit QTextFormat(int type);
@@ -229,8 +276,8 @@ public:
 
     void setProperty(int propertyId, const QVector<QTextLength> &lengths);
 
-
     QMap<int, QVariant> properties() const;
+    int propertyCount() const;
 
     inline void setObjectType(int type);
     inline int objectType() const
@@ -286,10 +333,29 @@ private:
 inline void QTextFormat::setObjectType(int atype)
 { setProperty(ObjectType, atype); }
 
+Q_DECLARE_OPERATORS_FOR_FLAGS(QTextFormat::PageBreakFlags)
+
 class Q_GUI_EXPORT QTextCharFormat : public QTextFormat
 {
 public:
-    enum VerticalAlignment { AlignNormal = 0, AlignSuperScript, AlignSubScript };
+    enum VerticalAlignment {
+        AlignNormal = 0,
+        AlignSuperScript,
+        AlignSubScript,
+        AlignMiddle,
+        AlignTop,
+        AlignBottom
+    };
+    enum UnderlineStyle { // keep in sync with Qt::PenStyle!
+        NoUnderline,
+        SingleUnderline,
+        DashUnderline,
+        DotLine,
+        DashDotLine,
+        DashDotDotLine,
+        WaveUnderline,
+        SpellCheckUnderline
+    };
 
     QTextCharFormat();
 
@@ -317,9 +383,8 @@ public:
     { return boolProperty(FontItalic); }
 
     inline void setFontUnderline(bool underline)
-    { setProperty(FontUnderline, underline); }
-    inline bool fontUnderline() const
-    { return boolProperty(FontUnderline); }
+    { setProperty(TextUnderlineStyle, underline ? SingleUnderline : NoUnderline); }
+    bool fontUnderline() const;
 
     inline void setFontOverline(bool overline)
     { setProperty(FontOverline, overline); }
@@ -341,6 +406,10 @@ public:
     inline bool fontFixedPitch() const
     { return boolProperty(FontFixedPitch); }
 
+    void setUnderlineStyle(UnderlineStyle style);
+    inline UnderlineStyle underlineStyle() const
+    { return static_cast<UnderlineStyle>(intProperty(TextUnderlineStyle)); }
+
     inline void setVerticalAlignment(VerticalAlignment alignment)
     { setProperty(TextVerticalAlignment, alignment); }
     inline VerticalAlignment verticalAlignment() const
@@ -351,6 +420,11 @@ public:
     inline QPen textOutline() const
     { return penProperty(TextOutline); }
 
+    inline void setToolTip(const QString &tip)
+    { setProperty(TextToolTip, tip); }
+    inline QString toolTip() const
+    { return stringProperty(TextToolTip); }
+
     inline void setAnchor(bool anchor)
     { setProperty(IsAnchor, anchor); }
     inline bool isAnchor() const
@@ -362,9 +436,12 @@ public:
     { return stringProperty(AnchorHref); }
 
     inline void setAnchorName(const QString &name)
-    { setProperty(AnchorName, name); }
-    inline QString anchorName() const
-    { return stringProperty(AnchorName); }
+    { setAnchorNames(QStringList(name)); }
+    QString anchorName() const;
+
+    inline void setAnchorNames(const QStringList &names)
+    { setProperty(AnchorName, names); }
+    QStringList anchorNames() const;
 
     inline void setTableCellRowSpan(int tableCellRowSpan);
     inline int tableCellRowSpan() const
@@ -397,7 +474,7 @@ public:
 
     inline void setAlignment(Qt::Alignment alignment);
     inline Qt::Alignment alignment() const
-    { return QFlag(intProperty(BlockAlignment)); }
+    { int a = intProperty(BlockAlignment); if (a == 0) a = Qt::AlignLeft; return QFlag(a); }
 
     inline void setTopMargin(qreal margin)
     { setProperty(BlockTopMargin, margin); }
@@ -432,6 +509,11 @@ public:
     { setProperty(BlockNonBreakableLines, b); }
     inline bool nonBreakableLines() const
     { return boolProperty(BlockNonBreakableLines); }
+
+    inline void setPageBreakPolicy(PageBreakFlags flags)
+    { setProperty(PageBreakPolicy, int(flags)); }
+    inline PageBreakFlags pageBreakPolicy() const
+    { return PageBreakFlags(intProperty(PageBreakPolicy)); }
 };
 
 inline void QTextBlockFormat::setAlignment(Qt::Alignment aalignment)
@@ -517,6 +599,20 @@ public:
 //        Absolute
     };
 
+    enum BorderStyle {
+        BorderStyle_None,
+        BorderStyle_Dotted,
+        BorderStyle_Dashed,
+        BorderStyle_Solid,
+        BorderStyle_Double,
+        BorderStyle_DotDash,
+        BorderStyle_DotDotDash,
+        BorderStyle_Groove,
+        BorderStyle_Ridge,
+        BorderStyle_Inset,
+        BorderStyle_Outset
+    };
+
     inline void setPosition(Position f)
     { setProperty(CssFloat, f); }
     inline Position position() const
@@ -526,10 +622,32 @@ public:
     inline qreal border() const
     { return doubleProperty(FrameBorder); }
 
-    inline void setMargin(qreal margin);
+    inline void setBorderBrush(const QBrush &brush)
+    { setProperty(FrameBorderBrush, brush); }
+    inline QBrush borderBrush() const
+    { return brushProperty(FrameBorderBrush); }
+
+    inline void setBorderStyle(BorderStyle style)
+    { setProperty(FrameBorderStyle, style); }
+    inline BorderStyle borderStyle() const
+    { return static_cast<BorderStyle>(intProperty(FrameBorderStyle)); }
+
+    void setMargin(qreal margin);
     inline qreal margin() const
     { return doubleProperty(FrameMargin); }
 
+    inline void setTopMargin(qreal margin);
+    qreal topMargin() const;
+
+    inline void setBottomMargin(qreal margin);
+    qreal bottomMargin() const;
+
+    inline void setLeftMargin(qreal margin);
+    qreal leftMargin() const;
+
+    inline void setRightMargin(qreal margin);
+    qreal rightMargin() const;
+
     inline void setPadding(qreal padding);
     inline qreal padding() const
     { return doubleProperty(FramePadding); }
@@ -544,14 +662,16 @@ public:
     inline void setHeight(const QTextLength &height);
     inline QTextLength height() const
     { return lengthProperty(FrameHeight); }
+
+    inline void setPageBreakPolicy(PageBreakFlags flags)
+    { setProperty(PageBreakPolicy, int(flags)); }
+    inline PageBreakFlags pageBreakPolicy() const
+    { return PageBreakFlags(intProperty(PageBreakPolicy)); }
 };
 
 inline void QTextFrameFormat::setBorder(qreal aborder)
 { setProperty(FrameBorder, aborder); }
 
-inline void QTextFrameFormat::setMargin(qreal amargin)
-{ setProperty(FrameMargin, amargin); }
-
 inline void QTextFrameFormat::setPadding(qreal apadding)
 { setProperty(FramePadding, apadding); }
 
@@ -563,6 +683,18 @@ inline void QTextFrameFormat::setHeight(qreal aheight)
 inline void QTextFrameFormat::setHeight(const QTextLength &aheight)
 { setProperty(FrameHeight, aheight); }
 
+inline void QTextFrameFormat::setTopMargin(qreal amargin)
+{ setProperty(FrameTopMargin, amargin); }
+
+inline void QTextFrameFormat::setBottomMargin(qreal amargin)
+{ setProperty(FrameBottomMargin, amargin); }
+
+inline void QTextFrameFormat::setLeftMargin(qreal amargin)
+{ setProperty(FrameLeftMargin, amargin); }
+
+inline void QTextFrameFormat::setRightMargin(qreal amargin)
+{ setProperty(FrameRightMargin, amargin); }
+
 class Q_GUI_EXPORT QTextTableFormat : public QTextFrameFormat
 {
 public:
@@ -595,6 +727,11 @@ public:
     inline void setAlignment(Qt::Alignment alignment);
     inline Qt::Alignment alignment() const
     { return QFlag(intProperty(BlockAlignment)); }
+
+    inline void setHeaderRowCount(int count)
+    { setProperty(TableHeaderRowCount, count); }
+    inline int headerRowCount() const
+    { return intProperty(TableHeaderRowCount); }
 };
 
 inline void QTextTableFormat::setColumns(int acolumns)
@@ -610,4 +747,6 @@ inline void QTextTableFormat::setCellPadding(qreal apadding)
 inline void QTextTableFormat::setAlignment(Qt::Alignment aalignment)
 { setProperty(BlockAlignment, int(aalignment)); }
 
+QT_END_HEADER
+
 #endif // QTEXTFORMAT_H
